import 'package:domain/generated/json/base/json_field.dart';
import 'package:domain/generated/json/revise_log_s_g_entity.g.dart';
import 'dart:convert';
export 'package:domain/generated/json/revise_log_s_g_entity.g.dart';

@JsonSerializable()
class ReviseLogSGEntity {
	List<ReviseLogSGRecords> records = [];

	ReviseLogSGEntity();

	factory ReviseLogSGEntity.fromJson(Map<String, dynamic> json) => $ReviseLogSGEntityFromJson(json);

	Map<String, dynamic> toJson() => $ReviseLogSGEntityToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class ReviseLogSGRecords {
	String? id = null;
	@JSONField(name: "operation_name")
	String? operationName = null;
	@JSONField(name: "data_type")
	int dataType = 0;
	String? desc = null;
	ReviseLogSGRecordsContent? content;
	@JSONField(name: "created_at")
	String? createdAt = null;
	@JSONField(name: "act_class")
	String? actClass = null;
	@JSONField(name: "act_text")
	String? actText = null;

	ReviseLogSGRecords();

	factory ReviseLogSGRecords.fromJson(Map<String, dynamic> json) => $ReviseLogSGRecordsFromJson(json);

	Map<String, dynamic> toJson() => $ReviseLogSGRecordsToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class ReviseLogSGRecordsContent {
	@JSONField(name: "revise_hours")
	ReviseLogSGRecordsOption? reviseHours;
	@JSONField(name: "revise_msg")
	ReviseLogSGRecordsOption? reviseMsg;
	ReviseLogSGRecordsOption? status;

	ReviseLogSGRecordsContent();

	factory ReviseLogSGRecordsContent.fromJson(Map<String, dynamic> json) => $ReviseLogSGRecordsContentFromJson(json);

	Map<String, dynamic> toJson() => $ReviseLogSGRecordsContentToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class ReviseLogSGRecordsOption {
	String? field = null;
	String? value = null;

	ReviseLogSGRecordsOption();

	factory ReviseLogSGRecordsOption.fromJson(Map<String, dynamic> json) => $ReviseLogSGRecordsOptionFromJson(json);

	Map<String, dynamic> toJson() => $ReviseLogSGRecordsOptionToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

